@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 BEGIN {
-  $CPAN::Perl::Releases::VERSION = '0.12';
+  $CPAN::Perl::Releases::VERSION = '0.14';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -18,316 +18,265 @@ use vars qw[@ISA @EXPORT_OK];
 our $data =
 {
   "5.003_07" => {
-    "tar.gz" => "A/AN/ANDYD/perl5.003_07.tar.gz"
+    "tar.gz" => "A/AN/ANDYD/perl5.003_07.tar.gz",
   },
   "5.004" => {
-    "tar.gz" => "C/CH/CHIPS/perl5.004.tar.gz"
+    "tar.gz" => "C/CH/CHIPS/perl5.004.tar.gz",
   },
   "5.004_01" => {
-    "tar.gz" => "T/TI/TIMB/perl5.004_01.tar.gz"
+    "tar.gz" => "T/TI/TIMB/perl5.004_01.tar.gz",
   },
   "5.004_02" => {
-    "tar.gz" => "T/TI/TIMB/perl5.004_02.tar.gz"
+    "tar.gz" => "T/TI/TIMB/perl5.004_02.tar.gz",
   },
   "5.004_03" => {
-    "tar.gz" => "T/TI/TIMB/perl5.004_03.tar.gz"
+    "tar.gz" => "T/TI/TIMB/perl5.004_03.tar.gz",
   },
   "5.004_04" => {
-    "tar.gz" => "T/TI/TIMB/perl5.004_04.tar.gz"
+    "tar.gz" => "T/TI/TIMB/perl5.004_04.tar.gz",
   },
   "5.004_05" => {
-    "tar.gz" => "C/CH/CHIPS/perl5.004_05.tar.gz"
+    "tar.gz" => "C/CH/CHIPS/perl5.004_05.tar.gz",
   },
   "5.005" => {
-    "tar.gz" => "G/GS/GSAR/perl5.005.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl5.005.tar.gz",
   },
   "5.005_01" => {
-    "tar.gz" => "G/GS/GSAR/perl5.005_01.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl5.005_01.tar.gz",
   },
   "5.005_02" => {
-    "tar.gz" => "G/GS/GSAR/perl5.005_02.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl5.005_02.tar.gz",
   },
   "5.005_03" => {
-    "tar.gz" => "G/GB/GBARR/perl5.005_03.tar.gz"
+    "tar.gz" => "G/GB/GBARR/perl5.005_03.tar.gz",
   },
   "5.005_04" => {
-    "tar.gz" => "L/LB/LBROCARD/perl5.005_04.tar.gz"
+    "tar.gz" => "L/LB/LBROCARD/perl5.005_04.tar.gz",
   },
   "5.10.0" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.10.0.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.10.0.tar.gz",
   },
   "5.10.0-RC1" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.10.0-RC1.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.10.0-RC1.tar.gz",
   },
   "5.10.0-RC2" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.10.0-RC2.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.10.0-RC2.tar.gz",
   },
   "5.10.1" => {
     "tar.bz2" => "D/DA/DAPM/perl-5.10.1.tar.bz2",
-    "tar.gz" => "D/DA/DAPM/perl-5.10.1.tar.gz"
-  },
-  "5.10.1-RC1" => {
-    "tar.bz2" => "D/DA/DAPM/perl-5.10.1-RC1.tar.bz2",
-    "tar.gz" => "D/DA/DAPM/perl-5.10.1-RC1.tar.gz"
-  },
-  "5.10.1-RC2" => {
-    "tar.bz2" => "D/DA/DAPM/perl-5.10.1-RC2.tar.bz2",
-    "tar.gz" => "D/DA/DAPM/perl-5.10.1-RC2.tar.gz"
+    "tar.gz" => "D/DA/DAPM/perl-5.10.1.tar.gz",
   },
   "5.11.0" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.11.0.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.11.0.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.11.0.tar.gz",
   },
   "5.11.1" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.11.1.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.11.1.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.11.1.tar.gz",
   },
   "5.11.2" => {
     "tar.bz2" => "L/LB/LBROCARD/perl-5.11.2.tar.bz2",
-    "tar.gz" => "L/LB/LBROCARD/perl-5.11.2.tar.gz"
+    "tar.gz" => "L/LB/LBROCARD/perl-5.11.2.tar.gz",
   },
   "5.11.3" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.11.3.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.11.3.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.11.3.tar.gz",
   },
   "5.11.4" => {
     "tar.bz2" => "R/RJ/RJBS/perl-5.11.4.tar.bz2",
-    "tar.gz" => "R/RJ/RJBS/perl-5.11.4.tar.gz"
+    "tar.gz" => "R/RJ/RJBS/perl-5.11.4.tar.gz",
   },
   "5.11.5" => {
     "tar.bz2" => "S/SH/SHAY/perl-5.11.5.tar.bz2",
-    "tar.gz" => "S/SH/SHAY/perl-5.11.5.tar.gz"
+    "tar.gz" => "S/SH/SHAY/perl-5.11.5.tar.gz",
   },
   "5.12.0" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.12.0.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.0.tar.gz"
-  },
-  "5.12.0-RC0" => {
-    "tar.gz" => "J/JE/JESSE/perl-5.12.0-RC0.tar.gz"
-  },
-  "5.12.0-RC1" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.12.0-RC1.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.0-RC1.tar.gz"
-  },
-  "5.12.0-RC2" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.12.0-RC2.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.0-RC2.tar.gz"
-  },
-  "5.12.0-RC3" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.12.0-RC3.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.0-RC3.tar.gz"
-  },
-  "5.12.0-RC4" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.12.0-RC4.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.0-RC4.tar.gz"
-  },
-  "5.12.0-RC5" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.12.0-RC5.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.0-RC5.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.12.0.tar.gz",
   },
   "5.12.1" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.12.1.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.1.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.12.1.tar.gz",
   },
   "5.12.1-RC1" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.12.1-RC1.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.1-RC1.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.12.1-RC1.tar.gz",
   },
   "5.12.1-RC2" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.12.1-RC2.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.1-RC2.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.12.1-RC2.tar.gz",
   },
   "5.12.2" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.12.2.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.2.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.12.2.tar.gz",
   },
   "5.12.2-RC1" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.12.2-RC1.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.12.2-RC1.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.12.2-RC1.tar.gz",
   },
   "5.12.3" => {
     "tar.bz2" => "R/RJ/RJBS/perl-5.12.3.tar.bz2",
-    "tar.gz" => "R/RJ/RJBS/perl-5.12.3.tar.gz"
-  },
-  "5.12.3-RC1" => {
-    "tar.bz2" => "R/RJ/RJBS/perl-5.12.3-RC1.tar.bz2",
-    "tar.gz" => "R/RJ/RJBS/perl-5.12.3-RC1.tar.gz"
-  },
-  "5.12.3-RC2" => {
-    "tar.bz2" => "R/RJ/RJBS/perl-5.12.3-RC2.tar.bz2",
-    "tar.gz" => "R/RJ/RJBS/perl-5.12.3-RC2.tar.gz"
-  },
-  "5.12.3-RC3" => {
-    "tar.bz2" => "R/RJ/RJBS/perl-5.12.3-RC3.tar.bz2",
-    "tar.gz" => "R/RJ/RJBS/perl-5.12.3-RC3.tar.gz"
+    "tar.gz" => "R/RJ/RJBS/perl-5.12.3.tar.gz",
   },
   "5.12.4-RC1" => {
     "tar.bz2" => "L/LB/LBROCARD/perl-5.12.4-RC1.tar.bz2",
-    "tar.gz" => "L/LB/LBROCARD/perl-5.12.4-RC1.tar.gz"
+    "tar.gz" => "L/LB/LBROCARD/perl-5.12.4-RC1.tar.gz",
   },
   "5.13.0" => {
     "tar.bz2" => "L/LB/LBROCARD/perl-5.13.0.tar.bz2",
-    "tar.gz" => "L/LB/LBROCARD/perl-5.13.0.tar.gz"
+    "tar.gz" => "L/LB/LBROCARD/perl-5.13.0.tar.gz",
   },
   "5.13.1" => {
     "tar.bz2" => "R/RJ/RJBS/perl-5.13.1.tar.bz2",
-    "tar.gz" => "R/RJ/RJBS/perl-5.13.1.tar.gz"
+    "tar.gz" => "R/RJ/RJBS/perl-5.13.1.tar.gz",
   },
   "5.13.10" => {
     "tar.bz2" => "A/AV/AVAR/perl-5.13.10.tar.bz2",
-    "tar.gz" => "A/AV/AVAR/perl-5.13.10.tar.gz"
+    "tar.gz" => "A/AV/AVAR/perl-5.13.10.tar.gz",
   },
   "5.13.11" => {
     "tar.bz2" => "F/FL/FLORA/perl-5.13.11.tar.bz2",
-    "tar.gz" => "F/FL/FLORA/perl-5.13.11.tar.gz"
+    "tar.gz" => "F/FL/FLORA/perl-5.13.11.tar.gz",
   },
   "5.13.2" => {
     "tar.bz2" => "M/MS/MSTROUT/perl-5.13.2.tar.bz2",
-    "tar.gz" => "M/MS/MSTROUT/perl-5.13.2.tar.gz"
+    "tar.gz" => "M/MS/MSTROUT/perl-5.13.2.tar.gz",
   },
   "5.13.3" => {
     "tar.bz2" => "D/DA/DAGOLDEN/perl-5.13.3.tar.bz2",
-    "tar.gz" => "D/DA/DAGOLDEN/perl-5.13.3.tar.gz"
+    "tar.gz" => "D/DA/DAGOLDEN/perl-5.13.3.tar.gz",
   },
   "5.13.4" => {
     "tar.bz2" => "F/FL/FLORA/perl-5.13.4.tar.bz2",
-    "tar.gz" => "F/FL/FLORA/perl-5.13.4.tar.gz"
+    "tar.gz" => "F/FL/FLORA/perl-5.13.4.tar.gz",
   },
   "5.13.5" => {
     "tar.bz2" => "S/SH/SHAY/perl-5.13.5.tar.bz2",
-    "tar.gz" => "S/SH/SHAY/perl-5.13.5.tar.gz"
+    "tar.gz" => "S/SH/SHAY/perl-5.13.5.tar.gz",
   },
   "5.13.6" => {
     "tar.bz2" => "M/MI/MIYAGAWA/perl-5.13.6.tar.bz2",
-    "tar.gz" => "M/MI/MIYAGAWA/perl-5.13.6.tar.gz"
+    "tar.gz" => "M/MI/MIYAGAWA/perl-5.13.6.tar.gz",
   },
   "5.13.7" => {
     "tar.bz2" => "B/BI/BINGOS/perl-5.13.7.tar.bz2",
-    "tar.gz" => "B/BI/BINGOS/perl-5.13.7.tar.gz"
+    "tar.gz" => "B/BI/BINGOS/perl-5.13.7.tar.gz",
   },
   "5.13.8" => {
     "tar.bz2" => "Z/ZE/ZEFRAM/perl-5.13.8.tar.bz2",
-    "tar.gz" => "Z/ZE/ZEFRAM/perl-5.13.8.tar.gz"
+    "tar.gz" => "Z/ZE/ZEFRAM/perl-5.13.8.tar.gz",
   },
   "5.13.9" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.13.9.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.13.9.tar.gz"
-  },
-  "5.14.0-RC1" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.14.0-RC1.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.14.0-RC1.tar.gz"
-  },
-  "5.14.0-RC2" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.14.0-RC2.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.14.0-RC2.tar.gz"
-  },
-  "5.14.0-RC3" => {
-    "tar.bz2" => "J/JE/JESSE/perl-5.14.0-RC3.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.14.0-RC3.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.13.9.tar.gz",
   },
   "5.14.0" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.14.0.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.14.0.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.14.0.tar.gz",
+  },
+  "5.14.0-RC1" => {
+    "tar.bz2" => "J/JE/JESSE/perl-5.14.0-RC1.tar.bz2",
+    "tar.gz" => "J/JE/JESSE/perl-5.14.0-RC1.tar.gz",
+  },
+  "5.14.0-RC2" => {
+    "tar.bz2" => "J/JE/JESSE/perl-5.14.0-RC2.tar.bz2",
+    "tar.gz" => "J/JE/JESSE/perl-5.14.0-RC2.tar.gz",
+  },
+  "5.14.0-RC3" => {
+    "tar.bz2" => "J/JE/JESSE/perl-5.14.0-RC3.tar.bz2",
+    "tar.gz" => "J/JE/JESSE/perl-5.14.0-RC3.tar.gz",
   },
   "5.14.1-RC1" => {
     "tar.bz2" => "J/JE/JESSE/perl-5.14.1-RC1.tar.bz2",
-    "tar.gz" => "J/JE/JESSE/perl-5.14.1-RC1.tar.gz"
+    "tar.gz" => "J/JE/JESSE/perl-5.14.1-RC1.tar.gz",
   },
   "5.6.0" => {
-    "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
   "5.6.1" => {
-    "tar.gz" => "G/GS/GSAR/perl-5.6.1.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl-5.6.1.tar.gz",
   },
   "5.6.1-TRIAL1" => {
-    "tar.gz" => "G/GS/GSAR/perl-5.6.1-TRIAL1.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl-5.6.1-TRIAL1.tar.gz",
   },
   "5.6.1-TRIAL2" => {
-    "tar.gz" => "G/GS/GSAR/perl-5.6.1-TRIAL2.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl-5.6.1-TRIAL2.tar.gz",
   },
   "5.6.1-TRIAL3" => {
-    "tar.gz" => "G/GS/GSAR/perl-5.6.1-TRIAL3.tar.gz"
+    "tar.gz" => "G/GS/GSAR/perl-5.6.1-TRIAL3.tar.gz",
   },
   "5.6.2" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.6.2.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.6.2.tar.gz",
   },
   "5.7.0" => {
-    "tar.gz" => "J/JH/JHI/perl-5.7.0.tar.gz"
+    "tar.gz" => "J/JH/JHI/perl-5.7.0.tar.gz",
   },
   "5.7.1" => {
-    "tar.gz" => "J/JH/JHI/perl-5.7.1.tar.gz"
+    "tar.gz" => "J/JH/JHI/perl-5.7.1.tar.gz",
   },
   "5.7.2" => {
-    "tar.gz" => "J/JH/JHI/perl-5.7.2.tar.gz"
+    "tar.gz" => "J/JH/JHI/perl-5.7.2.tar.gz",
   },
   "5.7.3" => {
-    "tar.gz" => "J/JH/JHI/perl-5.7.3.tar.gz"
+    "tar.gz" => "J/JH/JHI/perl-5.7.3.tar.gz",
   },
   "5.8.0" => {
-    "tar.gz" => "J/JH/JHI/perl-5.8.0.tar.gz"
+    "tar.gz" => "J/JH/JHI/perl-5.8.0.tar.gz",
   },
   "5.8.1" => {
-    "tar.gz" => "J/JH/JHI/perl-5.8.1.tar.gz"
+    "tar.gz" => "J/JH/JHI/perl-5.8.1.tar.gz",
   },
   "5.8.2" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.2.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.2.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.2.tar.gz",
   },
   "5.8.3" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.3.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.3.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.3.tar.gz",
   },
   "5.8.4" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.4.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.4.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.4.tar.gz",
   },
   "5.8.5" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.5.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.5.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.5.tar.gz",
   },
   "5.8.6" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.6.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.6.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.6.tar.gz",
   },
   "5.8.7" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.7.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.7.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.7.tar.gz",
   },
   "5.8.8" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.8.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.8.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.8.tar.gz",
   },
   "5.8.9" => {
     "tar.bz2" => "N/NW/NWCLARK/perl-5.8.9.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.9.tar.gz"
-  },
-  "5.8.9-RC1" => {
-    "tar.bz2" => "N/NW/NWCLARK/perl-5.8.9-RC1.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.9-RC1.tar.gz"
-  },
-  "5.8.9-RC2" => {
-    "tar.bz2" => "N/NW/NWCLARK/perl-5.8.9-RC2.tar.bz2",
-    "tar.gz" => "N/NW/NWCLARK/perl-5.8.9-RC2.tar.gz"
+    "tar.gz" => "N/NW/NWCLARK/perl-5.8.9.tar.gz",
   },
   "5.9.0" => {
     "tar.bz2" => "H/HV/HVDS/perl-5.9.0.tar.bz2",
-    "tar.gz" => "H/HV/HVDS/perl-5.9.0.tar.gz"
+    "tar.gz" => "H/HV/HVDS/perl-5.9.0.tar.gz",
   },
   "5.9.1" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.9.1.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.9.1.tar.gz",
   },
   "5.9.2" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.9.2.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.9.2.tar.gz",
   },
   "5.9.3" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.9.3.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.9.3.tar.gz",
   },
   "5.9.4" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.9.4.tar.gz"
+    "tar.gz" => "R/RG/RGARCIA/perl-5.9.4.tar.gz",
   },
   "5.9.5" => {
-    "tar.gz" => "R/RG/RGARCIA/perl-5.9.5.tar.gz"
-  }
+    "tar.gz" => "R/RG/RGARCIA/perl-5.9.5.tar.gz",
+  },
 };
 
 sub perl_tarballs {
@@ -349,7 +298,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.12
+version 0.14
 
 =head1 SYNOPSIS
 
